import os

#remove zip file if exists
def remove_zip(zip_name):
    if os.path.isfile(zip_name):
        os.remove(zip_name)
        print("ZIP file removed: " + zip_name)
    else:
        return "ZIP not exist: " + zip_name


import logging

def setup_logger(log_file):
    """
    Function to setup a logger for the script
    """
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    
    # create file handler which logs even debug messages
    fh = logging.FileHandler(log_file)
    fh.setLevel(logging.DEBUG)
    fh.setFormatter(formatter)
    logger.addHandler(fh)
    
    # create console handler with a higher log level
    ch = logging.StreamHandler()
    ch.setLevel(logging.ERROR)
    ch.setFormatter(formatter)
    logger.addHandler(ch)



import os
import logging

def check_upload_file(upload_file, version_name):
    # make sure not double / in path
    if upload_file.endswith("/"):
        upload_file = upload_file[:-1]
    # creating path from upload_file and version_name
    upload_file = upload_file + "/" + version_name
    logging.info("Checking upload file...")
    if os.path.isdir(upload_file):
        logging.info("Folder exists: " + upload_file)
        for root, dirs, files in os.walk(upload_file):
            for file in files:
                if file == "Packages.gz" or file == "Packages":
                    logging.info("Packages file found: " + file + " ,assuming this is a valid folder for upload")
                    return True
                else:
                    logging.error("Packages file not found: " + file)
                    return False
    else:
        logging.error("File not valid or not exist: " + upload_file)
        return False



import validators

def validate(radarType, version_name):
    radarTypearray = ["elvira", "iris", "birdradar"]
    if validators.length(radarType, min=1, max=50) == False:
        print("Radar type is not valid: " + radarType)
        exit()
    if radarType not in radarTypearray:
            print("Radar type is not valid: " + radarType)
            exit()
    else:
        print("Radar type is valid: " + radarType)
        
    if validators.length(version_name, min=1, max=20) == False:
        print("Version name is not valid: " + version_name)
        exit()
    else:
        print("Version name is valid: " + version_name)
        return radarType, version_name



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
from .logger import setup_logger
from .arg_parse import arg_parse

home_dir = os.path.expanduser("~")
config_file = home_dir + "/.config/robin/software_deployment.yaml"
log_filename = 'upload.log'


def main():
    setup_logger(log_filename)
    arg_parse(config_file)

if __name__ == "__main__":
    main()
